@@ -144,44 +144,122 @@ def login():
         raise Exception("Batchx token not set. Please run: bx.connect()")
 
 
-from . import user_pb2
-from . import user_pb2_grpc
-class UserService:
+from . import auth_pb2
+from . import auth_pb2_grpc
+class AuthService:
 
-    def GetUser(self, request):
+    def ConfirmForgotPassword(self, request):
         check()
-        return make_call(user_pb2_grpc.UserServiceStub(channel).GetUser, request)
+        return make_call(auth_pb2_grpc.AuthServiceStub(channel).ConfirmForgotPassword, request)
 
-    def UpdateUser(self, request):
+    def ConfirmSignup(self, request):
         check()
-        return make_call(user_pb2_grpc.UserServiceStub(channel).UpdateUser, request)
+        return make_call(auth_pb2_grpc.AuthServiceStub(channel).ConfirmSignup, request)
 
-    def GetUserRequest(self, **kwargs):
-        return user_pb2.GetUserRequest(**kwargs)
-
-    def GetUserResponse(self, **kwargs):
-        return user_pb2.GetUserResponse(**kwargs)
-
-    def UpdateUserRequest(self, **kwargs):
-        return user_pb2.UpdateUserRequest(**kwargs)
-
-    def UpdateUserResponse(self, **kwargs):
-        return user_pb2.UpdateUserResponse(**kwargs)
-
-
-from . import token_pb2
-from . import token_pb2_grpc
-class TokenService:
-
-    def AddToken(self, request):
+    def ForgotPassword(self, request):
         check()
-        return make_call(token_pb2_grpc.TokenServiceStub(channel).AddToken, request)
+        return make_call(auth_pb2_grpc.AuthServiceStub(channel).ForgotPassword, request)
 
-    def AddTokenRequest(self, **kwargs):
-        return token_pb2.AddTokenRequest(**kwargs)
+    def GoogleSignin(self, request):
+        check()
+        return make_call(auth_pb2_grpc.AuthServiceStub(channel).GoogleSignin, request)
 
-    def AddTokenResponse(self, **kwargs):
-        return token_pb2.AddTokenResponse(**kwargs)
+    def GoogleSignup(self, request):
+        check()
+        return make_call(auth_pb2_grpc.AuthServiceStub(channel).GoogleSignup, request)
+
+    def Login(self, request):
+        check()
+        return make_call(auth_pb2_grpc.AuthServiceStub(channel).Login, request)
+
+    def RefreshToken(self, request):
+        check()
+        return make_call(auth_pb2_grpc.AuthServiceStub(channel).RefreshToken, request)
+
+    def ResendSignupConfirmationCode(self, request):
+        check()
+        return make_call(auth_pb2_grpc.AuthServiceStub(channel).ResendSignupConfirmationCode, request)
+
+    def RevokeRefreshToken(self, request):
+        check()
+        return make_call(auth_pb2_grpc.AuthServiceStub(channel).RevokeRefreshToken, request)
+
+    def Signup(self, request):
+        check()
+        return make_call(auth_pb2_grpc.AuthServiceStub(channel).Signup, request)
+
+    def StartSignup(self, request):
+        check()
+        return make_call(auth_pb2_grpc.AuthServiceStub(channel).StartSignup, request)
+
+    def ConfirmForgotPasswordRequest(self, **kwargs):
+        return auth_pb2.ConfirmForgotPasswordRequest(**kwargs)
+
+    def ConfirmForgotPasswordResponse(self, **kwargs):
+        return auth_pb2.ConfirmForgotPasswordResponse(**kwargs)
+
+    def ConfirmSignupRequest(self, **kwargs):
+        return auth_pb2.ConfirmSignupRequest(**kwargs)
+
+    def ConfirmSignupResponse(self, **kwargs):
+        return auth_pb2.ConfirmSignupResponse(**kwargs)
+
+    def ForgotPasswordRequest(self, **kwargs):
+        return auth_pb2.ForgotPasswordRequest(**kwargs)
+
+    def ForgotPasswordResponse(self, **kwargs):
+        return auth_pb2.ForgotPasswordResponse(**kwargs)
+
+    def GoogleSigninRequest(self, **kwargs):
+        return auth_pb2.GoogleSigninRequest(**kwargs)
+
+    def GoogleSigninResponse(self, **kwargs):
+        return auth_pb2.GoogleSigninResponse(**kwargs)
+
+    def GoogleSignupRequest(self, **kwargs):
+        return auth_pb2.GoogleSignupRequest(**kwargs)
+
+    def GoogleSignupResponse(self, **kwargs):
+        return auth_pb2.GoogleSignupResponse(**kwargs)
+
+    def LoginRequest(self, **kwargs):
+        return auth_pb2.LoginRequest(**kwargs)
+
+    def LoginResponse(self, **kwargs):
+        return auth_pb2.LoginResponse(**kwargs)
+
+    def RefreshTokenRequest(self, **kwargs):
+        return auth_pb2.RefreshTokenRequest(**kwargs)
+
+    def RefreshTokenResponse(self, **kwargs):
+        return auth_pb2.RefreshTokenResponse(**kwargs)
+
+    def ResendSignupConfirmationCodeRequest(self, **kwargs):
+        return auth_pb2.ResendSignupConfirmationCodeRequest(**kwargs)
+
+    def ResendSignupConfirmationCodeResponse(self, **kwargs):
+        return auth_pb2.ResendSignupConfirmationCodeResponse(**kwargs)
+
+    def RevokeRefreshTokenRequest(self, **kwargs):
+        return auth_pb2.RevokeRefreshTokenRequest(**kwargs)
+
+    def RevokeRefreshTokenResponse(self, **kwargs):
+        return auth_pb2.RevokeRefreshTokenResponse(**kwargs)
+
+    def SignupRequest(self, **kwargs):
+        return auth_pb2.SignupRequest(**kwargs)
+
+    def SignupResponse(self, **kwargs):
+        return auth_pb2.SignupResponse(**kwargs)
+
+    def StartSignupRequest(self, **kwargs):
+        return auth_pb2.StartSignupRequest(**kwargs)
+
+    def StartSignupResponse(self, **kwargs):
+        return auth_pb2.StartSignupResponse(**kwargs)
+
+    def TokenResponse(self, **kwargs):
+        return auth_pb2.TokenResponse(**kwargs)
 
 
 from . import provider_pb2
@@ -330,6 +408,111 @@ class OrganizationService:
         return organization_pb2.UpdateOrganizationResponse(**kwargs)
 
 
+from . import alert_pb2
+from . import alert_pb2_grpc
+class AlertService:
+
+    def DismissAlert(self, request):
+        check()
+        return make_call(alert_pb2_grpc.AlertServiceStub(channel).DismissAlert, request)
+
+    def DismissAllAlerts(self, request):
+        check()
+        return make_call(alert_pb2_grpc.AlertServiceStub(channel).DismissAllAlerts, request)
+
+    def ListAlerts(self, request):
+        check()
+        return make_call(alert_pb2_grpc.AlertServiceStub(channel).ListAlerts, request)
+
+    def Alert(self, **kwargs):
+        return alert_pb2.Alert(**kwargs)
+
+    def DismissAlertRequest(self, **kwargs):
+        return alert_pb2.DismissAlertRequest(**kwargs)
+
+    def DismissAlertResponse(self, **kwargs):
+        return alert_pb2.DismissAlertResponse(**kwargs)
+
+    def DismissAllAlertsRequest(self, **kwargs):
+        return alert_pb2.DismissAllAlertsRequest(**kwargs)
+
+    def DismissAllAlertsResponse(self, **kwargs):
+        return alert_pb2.DismissAllAlertsResponse(**kwargs)
+
+    def ListAlertsRequest(self, **kwargs):
+        return alert_pb2.ListAlertsRequest(**kwargs)
+
+    def ListAlertsResponse(self, **kwargs):
+        return alert_pb2.ListAlertsResponse(**kwargs)
+
+
+from . import consumer_pb2
+from . import consumer_pb2_grpc
+class ConsumerService:
+
+    def GetMetrics(self, request):
+        check()
+        return make_call(consumer_pb2_grpc.ConsumerServiceStub(channel).GetMetrics, request)
+
+    def GetMetricsRequest(self, **kwargs):
+        return consumer_pb2.GetMetricsRequest(**kwargs)
+
+    def GetMetricsResponse(self, **kwargs):
+        return consumer_pb2.GetMetricsResponse(**kwargs)
+
+
+from . import health_pb2
+from . import health_pb2_grpc
+class HealthService:
+
+    def HealthCheckRequest(self, **kwargs):
+        return health_pb2.HealthCheckRequest(**kwargs)
+
+    def HealthCheckResponse(self, **kwargs):
+        return health_pb2.HealthCheckResponse(**kwargs)
+
+
+from . import profile_pb2
+from . import profile_pb2_grpc
+class ProfileService:
+
+    def Profile(self, **kwargs):
+        return profile_pb2.Profile(**kwargs)
+
+
+from . import audit_pb2
+from . import audit_pb2_grpc
+class AuditService:
+
+    def ListEvents(self, request):
+        check()
+        return make_call(audit_pb2_grpc.AuditServiceStub(channel).ListEvents, request)
+
+    def Event(self, **kwargs):
+        return audit_pb2.Event(**kwargs)
+
+    def ListEventsRequest(self, **kwargs):
+        return audit_pb2.ListEventsRequest(**kwargs)
+
+    def ListEventsResponse(self, **kwargs):
+        return audit_pb2.ListEventsResponse(**kwargs)
+
+
+from . import token_pb2
+from . import token_pb2_grpc
+class TokenService:
+
+    def AddToken(self, request):
+        check()
+        return make_call(token_pb2_grpc.TokenServiceStub(channel).AddToken, request)
+
+    def AddTokenRequest(self, **kwargs):
+        return token_pb2.AddTokenRequest(**kwargs)
+
+    def AddTokenResponse(self, **kwargs):
+        return token_pb2.AddTokenResponse(**kwargs)
+
+
 from . import image_pb2
 from . import image_pb2_grpc
 class ImageService:
@@ -472,255 +655,6 @@ class ImageService:
         return image_pb2.TagImageResponse(**kwargs)
 
 
-from . import picture_pb2
-from . import picture_pb2_grpc
-class PictureService:
-
-    def CompleteUpload(self, request):
-        check()
-        return make_call(picture_pb2_grpc.PictureServiceStub(channel).CompleteUpload, request)
-
-    def CropPicture(self, request):
-        check()
-        return make_call(picture_pb2_grpc.PictureServiceStub(channel).CropPicture, request)
-
-    def Upload(self, request):
-        check()
-        return make_call(picture_pb2_grpc.PictureServiceStub(channel).Upload, request)
-
-    def UploadPresigned(self, request):
-        check()
-        return make_call(picture_pb2_grpc.PictureServiceStub(channel).UploadPresigned, request)
-
-    def CompleteUploadRequest(self, **kwargs):
-        return picture_pb2.CompleteUploadRequest(**kwargs)
-
-    def CompleteUploadResponse(self, **kwargs):
-        return picture_pb2.CompleteUploadResponse(**kwargs)
-
-    def CropPictureRequest(self, **kwargs):
-        return picture_pb2.CropPictureRequest(**kwargs)
-
-    def CropPictureResponse(self, **kwargs):
-        return picture_pb2.CropPictureResponse(**kwargs)
-
-    def UploadPresignedRequest(self, **kwargs):
-        return picture_pb2.UploadPresignedRequest(**kwargs)
-
-    def UploadPresignedResponse(self, **kwargs):
-        return picture_pb2.UploadPresignedResponse(**kwargs)
-
-    def UploadRequest(self, **kwargs):
-        return picture_pb2.UploadRequest(**kwargs)
-
-    def UploadResponse(self, **kwargs):
-        return picture_pb2.UploadResponse(**kwargs)
-
-
-from . import profile_pb2
-from . import profile_pb2_grpc
-class ProfileService:
-
-    def Profile(self, **kwargs):
-        return profile_pb2.Profile(**kwargs)
-
-
-from . import alert_pb2
-from . import alert_pb2_grpc
-class AlertService:
-
-    def DismissAlert(self, request):
-        check()
-        return make_call(alert_pb2_grpc.AlertServiceStub(channel).DismissAlert, request)
-
-    def DismissAllAlerts(self, request):
-        check()
-        return make_call(alert_pb2_grpc.AlertServiceStub(channel).DismissAllAlerts, request)
-
-    def ListAlerts(self, request):
-        check()
-        return make_call(alert_pb2_grpc.AlertServiceStub(channel).ListAlerts, request)
-
-    def Alert(self, **kwargs):
-        return alert_pb2.Alert(**kwargs)
-
-    def DismissAlertRequest(self, **kwargs):
-        return alert_pb2.DismissAlertRequest(**kwargs)
-
-    def DismissAlertResponse(self, **kwargs):
-        return alert_pb2.DismissAlertResponse(**kwargs)
-
-    def DismissAllAlertsRequest(self, **kwargs):
-        return alert_pb2.DismissAllAlertsRequest(**kwargs)
-
-    def DismissAllAlertsResponse(self, **kwargs):
-        return alert_pb2.DismissAllAlertsResponse(**kwargs)
-
-    def ListAlertsRequest(self, **kwargs):
-        return alert_pb2.ListAlertsRequest(**kwargs)
-
-    def ListAlertsResponse(self, **kwargs):
-        return alert_pb2.ListAlertsResponse(**kwargs)
-
-
-from . import log_pb2
-from . import log_pb2_grpc
-class LogService:
-
-    def LogRecord(self, **kwargs):
-        return log_pb2.LogRecord(**kwargs)
-
-
-from . import auth_pb2
-from . import auth_pb2_grpc
-class AuthService:
-
-    def ConfirmForgotPassword(self, request):
-        check()
-        return make_call(auth_pb2_grpc.AuthServiceStub(channel).ConfirmForgotPassword, request)
-
-    def ConfirmSignup(self, request):
-        check()
-        return make_call(auth_pb2_grpc.AuthServiceStub(channel).ConfirmSignup, request)
-
-    def ForgotPassword(self, request):
-        check()
-        return make_call(auth_pb2_grpc.AuthServiceStub(channel).ForgotPassword, request)
-
-    def GoogleSignin(self, request):
-        check()
-        return make_call(auth_pb2_grpc.AuthServiceStub(channel).GoogleSignin, request)
-
-    def GoogleSignup(self, request):
-        check()
-        return make_call(auth_pb2_grpc.AuthServiceStub(channel).GoogleSignup, request)
-
-    def Login(self, request):
-        check()
-        return make_call(auth_pb2_grpc.AuthServiceStub(channel).Login, request)
-
-    def RefreshToken(self, request):
-        check()
-        return make_call(auth_pb2_grpc.AuthServiceStub(channel).RefreshToken, request)
-
-    def ResendSignupConfirmationCode(self, request):
-        check()
-        return make_call(auth_pb2_grpc.AuthServiceStub(channel).ResendSignupConfirmationCode, request)
-
-    def RevokeRefreshToken(self, request):
-        check()
-        return make_call(auth_pb2_grpc.AuthServiceStub(channel).RevokeRefreshToken, request)
-
-    def Signup(self, request):
-        check()
-        return make_call(auth_pb2_grpc.AuthServiceStub(channel).Signup, request)
-
-    def StartSignup(self, request):
-        check()
-        return make_call(auth_pb2_grpc.AuthServiceStub(channel).StartSignup, request)
-
-    def ConfirmForgotPasswordRequest(self, **kwargs):
-        return auth_pb2.ConfirmForgotPasswordRequest(**kwargs)
-
-    def ConfirmForgotPasswordResponse(self, **kwargs):
-        return auth_pb2.ConfirmForgotPasswordResponse(**kwargs)
-
-    def ConfirmSignupRequest(self, **kwargs):
-        return auth_pb2.ConfirmSignupRequest(**kwargs)
-
-    def ConfirmSignupResponse(self, **kwargs):
-        return auth_pb2.ConfirmSignupResponse(**kwargs)
-
-    def ForgotPasswordRequest(self, **kwargs):
-        return auth_pb2.ForgotPasswordRequest(**kwargs)
-
-    def ForgotPasswordResponse(self, **kwargs):
-        return auth_pb2.ForgotPasswordResponse(**kwargs)
-
-    def GoogleSigninRequest(self, **kwargs):
-        return auth_pb2.GoogleSigninRequest(**kwargs)
-
-    def GoogleSigninResponse(self, **kwargs):
-        return auth_pb2.GoogleSigninResponse(**kwargs)
-
-    def GoogleSignupRequest(self, **kwargs):
-        return auth_pb2.GoogleSignupRequest(**kwargs)
-
-    def GoogleSignupResponse(self, **kwargs):
-        return auth_pb2.GoogleSignupResponse(**kwargs)
-
-    def LoginRequest(self, **kwargs):
-        return auth_pb2.LoginRequest(**kwargs)
-
-    def LoginResponse(self, **kwargs):
-        return auth_pb2.LoginResponse(**kwargs)
-
-    def RefreshTokenRequest(self, **kwargs):
-        return auth_pb2.RefreshTokenRequest(**kwargs)
-
-    def RefreshTokenResponse(self, **kwargs):
-        return auth_pb2.RefreshTokenResponse(**kwargs)
-
-    def ResendSignupConfirmationCodeRequest(self, **kwargs):
-        return auth_pb2.ResendSignupConfirmationCodeRequest(**kwargs)
-
-    def ResendSignupConfirmationCodeResponse(self, **kwargs):
-        return auth_pb2.ResendSignupConfirmationCodeResponse(**kwargs)
-
-    def RevokeRefreshTokenRequest(self, **kwargs):
-        return auth_pb2.RevokeRefreshTokenRequest(**kwargs)
-
-    def RevokeRefreshTokenResponse(self, **kwargs):
-        return auth_pb2.RevokeRefreshTokenResponse(**kwargs)
-
-    def SignupRequest(self, **kwargs):
-        return auth_pb2.SignupRequest(**kwargs)
-
-    def SignupResponse(self, **kwargs):
-        return auth_pb2.SignupResponse(**kwargs)
-
-    def StartSignupRequest(self, **kwargs):
-        return auth_pb2.StartSignupRequest(**kwargs)
-
-    def StartSignupResponse(self, **kwargs):
-        return auth_pb2.StartSignupResponse(**kwargs)
-
-    def TokenResponse(self, **kwargs):
-        return auth_pb2.TokenResponse(**kwargs)
-
-
-from . import common_pb2
-from . import common_pb2_grpc
-class CommonService:
-
-    def IntRangeFilter(self, **kwargs):
-        return common_pb2.IntRangeFilter(**kwargs)
-
-    def LongRangeFilter(self, **kwargs):
-        return common_pb2.LongRangeFilter(**kwargs)
-
-    def Organization(self, **kwargs):
-        return common_pb2.Organization(**kwargs)
-
-    def PageInfo(self, **kwargs):
-        return common_pb2.PageInfo(**kwargs)
-
-    def Picture(self, **kwargs):
-        return common_pb2.Picture(**kwargs)
-
-    def RateLimit(self, **kwargs):
-        return common_pb2.RateLimit(**kwargs)
-
-    def Region(self, **kwargs):
-        return common_pb2.Region(**kwargs)
-
-    def Thumbnail(self, **kwargs):
-        return common_pb2.Thumbnail(**kwargs)
-
-    def User(self, **kwargs):
-        return common_pb2.User(**kwargs)
-
-
 from . import tag_pb2
 from . import tag_pb2_grpc
 class TagService:
@@ -795,210 +729,6 @@ class TagService:
         return tag_pb2.UpdateTagResponse(**kwargs)
 
 
-from . import billing_pb2
-from . import billing_pb2_grpc
-class BillingService:
-
-    def CreatePaymentIntent(self, request):
-        check()
-        return make_call(billing_pb2_grpc.BillingServiceStub(channel).CreatePaymentIntent, request)
-
-    def CreatePaymentIntentRequest(self, **kwargs):
-        return billing_pb2.CreatePaymentIntentRequest(**kwargs)
-
-    def CreatePaymentIntentResponse(self, **kwargs):
-        return billing_pb2.CreatePaymentIntentResponse(**kwargs)
-
-
-from . import health_pb2
-from . import health_pb2_grpc
-class HealthService:
-
-    def HealthCheckRequest(self, **kwargs):
-        return health_pb2.HealthCheckRequest(**kwargs)
-
-    def HealthCheckResponse(self, **kwargs):
-        return health_pb2.HealthCheckResponse(**kwargs)
-
-
-from . import filesystem_pb2
-from . import filesystem_pb2_grpc
-class FilesystemService:
-
-    def CancelUpload(self, request):
-        check()
-        return make_call(filesystem_pb2_grpc.FilesystemServiceStub(channel).CancelUpload, request)
-
-    def CompleteUpload(self, request):
-        check()
-        return make_call(filesystem_pb2_grpc.FilesystemServiceStub(channel).CompleteUpload, request)
-
-    def Copy(self, request):
-        check()
-        return make_call(filesystem_pb2_grpc.FilesystemServiceStub(channel).Copy, request)
-
-    def DeleteFile(self, request):
-        check()
-        return make_call(filesystem_pb2_grpc.FilesystemServiceStub(channel).DeleteFile, request)
-
-    def DownloadPresigned(self, request):
-        check()
-        return make_call(filesystem_pb2_grpc.FilesystemServiceStub(channel).DownloadPresigned, request)
-
-    def GetBlob(self, request):
-        check()
-        return make_call(filesystem_pb2_grpc.FilesystemServiceStub(channel).GetBlob, request)
-
-    def GetFile(self, request):
-        check()
-        return make_call(filesystem_pb2_grpc.FilesystemServiceStub(channel).GetFile, request)
-
-    def ListBlobPointers(self, request):
-        check()
-        return make_call(filesystem_pb2_grpc.FilesystemServiceStub(channel).ListBlobPointers, request)
-
-    def ListBlobs(self, request):
-        check()
-        return make_call(filesystem_pb2_grpc.FilesystemServiceStub(channel).ListBlobs, request)
-
-    def ListFolder(self, request):
-        check()
-        return make_call(filesystem_pb2_grpc.FilesystemServiceStub(channel).ListFolder, request)
-
-    def ReportUploadStatus(self, request):
-        check()
-        return make_call(filesystem_pb2_grpc.FilesystemServiceStub(channel).ReportUploadStatus, request)
-
-    def SetBlobStatus(self, request):
-        check()
-        return make_call(filesystem_pb2_grpc.FilesystemServiceStub(channel).SetBlobStatus, request)
-
-    def ShareFile(self, request):
-        check()
-        return make_call(filesystem_pb2_grpc.FilesystemServiceStub(channel).ShareFile, request)
-
-    def UploadPresigned(self, request):
-        check()
-        return make_call(filesystem_pb2_grpc.FilesystemServiceStub(channel).UploadPresigned, request)
-
-    def Blob(self, **kwargs):
-        return filesystem_pb2.Blob(**kwargs)
-
-    def CancelUploadRequest(self, **kwargs):
-        return filesystem_pb2.CancelUploadRequest(**kwargs)
-
-    def CancelUploadResponse(self, **kwargs):
-        return filesystem_pb2.CancelUploadResponse(**kwargs)
-
-    def CompleteUploadRequest(self, **kwargs):
-        return filesystem_pb2.CompleteUploadRequest(**kwargs)
-
-    def CompleteUploadResponse(self, **kwargs):
-        return filesystem_pb2.CompleteUploadResponse(**kwargs)
-
-    def CopyRequest(self, **kwargs):
-        return filesystem_pb2.CopyRequest(**kwargs)
-
-    def CreateFolderRequest(self, **kwargs):
-        return filesystem_pb2.CreateFolderRequest(**kwargs)
-
-    def CreateFolderResponse(self, **kwargs):
-        return filesystem_pb2.CreateFolderResponse(**kwargs)
-
-    def DeleteFileRequest(self, **kwargs):
-        return filesystem_pb2.DeleteFileRequest(**kwargs)
-
-    def DeleteFileResponse(self, **kwargs):
-        return filesystem_pb2.DeleteFileResponse(**kwargs)
-
-    def DeleteFolderRequest(self, **kwargs):
-        return filesystem_pb2.DeleteFolderRequest(**kwargs)
-
-    def DeleteFolderResponse(self, **kwargs):
-        return filesystem_pb2.DeleteFolderResponse(**kwargs)
-
-    def DownloadPresignedRequest(self, **kwargs):
-        return filesystem_pb2.DownloadPresignedRequest(**kwargs)
-
-    def DownloadPresignedResponse(self, **kwargs):
-        return filesystem_pb2.DownloadPresignedResponse(**kwargs)
-
-    def File(self, **kwargs):
-        return filesystem_pb2.File(**kwargs)
-
-    def GetBlobRequest(self, **kwargs):
-        return filesystem_pb2.GetBlobRequest(**kwargs)
-
-    def GetBlobResponse(self, **kwargs):
-        return filesystem_pb2.GetBlobResponse(**kwargs)
-
-    def GetFileRequest(self, **kwargs):
-        return filesystem_pb2.GetFileRequest(**kwargs)
-
-    def GetFileResponse(self, **kwargs):
-        return filesystem_pb2.GetFileResponse(**kwargs)
-
-    def ListBlobPointersRequest(self, **kwargs):
-        return filesystem_pb2.ListBlobPointersRequest(**kwargs)
-
-    def ListBlobPointersResponse(self, **kwargs):
-        return filesystem_pb2.ListBlobPointersResponse(**kwargs)
-
-    def ListBlobsRequest(self, **kwargs):
-        return filesystem_pb2.ListBlobsRequest(**kwargs)
-
-    def ListBlobsResponse(self, **kwargs):
-        return filesystem_pb2.ListBlobsResponse(**kwargs)
-
-    def ListFolderRequest(self, **kwargs):
-        return filesystem_pb2.ListFolderRequest(**kwargs)
-
-    def ListFolderResponse(self, **kwargs):
-        return filesystem_pb2.ListFolderResponse(**kwargs)
-
-    def Metadata(self, **kwargs):
-        return filesystem_pb2.Metadata(**kwargs)
-
-    def ReportUploadStatusRequest(self, **kwargs):
-        return filesystem_pb2.ReportUploadStatusRequest(**kwargs)
-
-    def ReportUploadStatusResponse(self, **kwargs):
-        return filesystem_pb2.ReportUploadStatusResponse(**kwargs)
-
-    def SetBlobStatusRequest(self, **kwargs):
-        return filesystem_pb2.SetBlobStatusRequest(**kwargs)
-
-    def SetBlobStatusResponse(self, **kwargs):
-        return filesystem_pb2.SetBlobStatusResponse(**kwargs)
-
-    def ShareFileRequest(self, **kwargs):
-        return filesystem_pb2.ShareFileRequest(**kwargs)
-
-    def ShareFileResponse(self, **kwargs):
-        return filesystem_pb2.ShareFileResponse(**kwargs)
-
-    def UploadPresignedRequest(self, **kwargs):
-        return filesystem_pb2.UploadPresignedRequest(**kwargs)
-
-    def UploadPresignedResponse(self, **kwargs):
-        return filesystem_pb2.UploadPresignedResponse(**kwargs)
-
-
-from . import consumer_pb2
-from . import consumer_pb2_grpc
-class ConsumerService:
-
-    def GetMetrics(self, request):
-        check()
-        return make_call(consumer_pb2_grpc.ConsumerServiceStub(channel).GetMetrics, request)
-
-    def GetMetricsRequest(self, **kwargs):
-        return consumer_pb2.GetMetricsRequest(**kwargs)
-
-    def GetMetricsResponse(self, **kwargs):
-        return consumer_pb2.GetMetricsResponse(**kwargs)
-
-
 from . import environment_pb2
 from . import environment_pb2_grpc
 class EnvironmentService:
@@ -1037,6 +767,14 @@ class EnvironmentService:
         return environment_pb2.Region(**kwargs)
 
 
+from . import log_pb2
+from . import log_pb2_grpc
+class LogService:
+
+    def LogRecord(self, **kwargs):
+        return log_pb2.LogRecord(**kwargs)
+
+
 from . import admin_pb2
 from . import admin_pb2_grpc
 class AdminService:
@@ -1125,22 +863,110 @@ class AdminService:
         return admin_pb2.SetGlobalPropertyResponse(**kwargs)
 
 
-from . import audit_pb2
-from . import audit_pb2_grpc
-class AuditService:
+from . import user_pb2
+from . import user_pb2_grpc
+class UserService:
 
-    def ListEvents(self, request):
+    def GetUser(self, request):
         check()
-        return make_call(audit_pb2_grpc.AuditServiceStub(channel).ListEvents, request)
+        return make_call(user_pb2_grpc.UserServiceStub(channel).GetUser, request)
 
-    def Event(self, **kwargs):
-        return audit_pb2.Event(**kwargs)
+    def UpdateUser(self, request):
+        check()
+        return make_call(user_pb2_grpc.UserServiceStub(channel).UpdateUser, request)
 
-    def ListEventsRequest(self, **kwargs):
-        return audit_pb2.ListEventsRequest(**kwargs)
+    def GetUserRequest(self, **kwargs):
+        return user_pb2.GetUserRequest(**kwargs)
 
-    def ListEventsResponse(self, **kwargs):
-        return audit_pb2.ListEventsResponse(**kwargs)
+    def GetUserResponse(self, **kwargs):
+        return user_pb2.GetUserResponse(**kwargs)
+
+    def UpdateUserRequest(self, **kwargs):
+        return user_pb2.UpdateUserRequest(**kwargs)
+
+    def UpdateUserResponse(self, **kwargs):
+        return user_pb2.UpdateUserResponse(**kwargs)
+
+
+from . import picture_pb2
+from . import picture_pb2_grpc
+class PictureService:
+
+    def CompleteUpload(self, request):
+        check()
+        return make_call(picture_pb2_grpc.PictureServiceStub(channel).CompleteUpload, request)
+
+    def CropPicture(self, request):
+        check()
+        return make_call(picture_pb2_grpc.PictureServiceStub(channel).CropPicture, request)
+
+    def Upload(self, request):
+        check()
+        return make_call(picture_pb2_grpc.PictureServiceStub(channel).Upload, request)
+
+    def UploadPresigned(self, request):
+        check()
+        return make_call(picture_pb2_grpc.PictureServiceStub(channel).UploadPresigned, request)
+
+    def CompleteUploadRequest(self, **kwargs):
+        return picture_pb2.CompleteUploadRequest(**kwargs)
+
+    def CompleteUploadResponse(self, **kwargs):
+        return picture_pb2.CompleteUploadResponse(**kwargs)
+
+    def CropPictureRequest(self, **kwargs):
+        return picture_pb2.CropPictureRequest(**kwargs)
+
+    def CropPictureResponse(self, **kwargs):
+        return picture_pb2.CropPictureResponse(**kwargs)
+
+    def UploadPresignedRequest(self, **kwargs):
+        return picture_pb2.UploadPresignedRequest(**kwargs)
+
+    def UploadPresignedResponse(self, **kwargs):
+        return picture_pb2.UploadPresignedResponse(**kwargs)
+
+    def UploadRequest(self, **kwargs):
+        return picture_pb2.UploadRequest(**kwargs)
+
+    def UploadResponse(self, **kwargs):
+        return picture_pb2.UploadResponse(**kwargs)
+
+
+from . import billing_pb2
+from . import billing_pb2_grpc
+class BillingService:
+
+    def CreatePaymentIntent(self, request):
+        check()
+        return make_call(billing_pb2_grpc.BillingServiceStub(channel).CreatePaymentIntent, request)
+
+    def ListCharges(self, request):
+        check()
+        return make_call(billing_pb2_grpc.BillingServiceStub(channel).ListCharges, request)
+
+    def Charge(self, **kwargs):
+        return billing_pb2.Charge(**kwargs)
+
+    def CreatePaymentIntentRequest(self, **kwargs):
+        return billing_pb2.CreatePaymentIntentRequest(**kwargs)
+
+    def CreatePaymentIntentResponse(self, **kwargs):
+        return billing_pb2.CreatePaymentIntentResponse(**kwargs)
+
+    def ListChargesRequest(self, **kwargs):
+        return billing_pb2.ListChargesRequest(**kwargs)
+
+    def ListChargesResponse(self, **kwargs):
+        return billing_pb2.ListChargesResponse(**kwargs)
+
+
+from . import docker_pb2
+from . import docker_pb2_grpc
+class DockerService:
+
+    def DockerImageCoordinates(self, **kwargs):
+        return docker_pb2.DockerImageCoordinates(**kwargs)
 
 
 from . import job_pb2
@@ -1342,10 +1168,197 @@ class JobService:
         return job_pb2.Workflow(**kwargs)
 
 
-from . import docker_pb2
-from . import docker_pb2_grpc
-class DockerService:
+from . import filesystem_pb2
+from . import filesystem_pb2_grpc
+class FilesystemService:
 
-    def DockerImageCoordinates(self, **kwargs):
-        return docker_pb2.DockerImageCoordinates(**kwargs)
+    def CancelUpload(self, request):
+        check()
+        return make_call(filesystem_pb2_grpc.FilesystemServiceStub(channel).CancelUpload, request)
+
+    def CompleteUpload(self, request):
+        check()
+        return make_call(filesystem_pb2_grpc.FilesystemServiceStub(channel).CompleteUpload, request)
+
+    def Copy(self, request):
+        check()
+        return make_call(filesystem_pb2_grpc.FilesystemServiceStub(channel).Copy, request)
+
+    def DeleteFile(self, request):
+        check()
+        return make_call(filesystem_pb2_grpc.FilesystemServiceStub(channel).DeleteFile, request)
+
+    def DownloadPresigned(self, request):
+        check()
+        return make_call(filesystem_pb2_grpc.FilesystemServiceStub(channel).DownloadPresigned, request)
+
+    def GetBlob(self, request):
+        check()
+        return make_call(filesystem_pb2_grpc.FilesystemServiceStub(channel).GetBlob, request)
+
+    def GetFile(self, request):
+        check()
+        return make_call(filesystem_pb2_grpc.FilesystemServiceStub(channel).GetFile, request)
+
+    def ListBlobPointers(self, request):
+        check()
+        return make_call(filesystem_pb2_grpc.FilesystemServiceStub(channel).ListBlobPointers, request)
+
+    def ListBlobs(self, request):
+        check()
+        return make_call(filesystem_pb2_grpc.FilesystemServiceStub(channel).ListBlobs, request)
+
+    def ListFolder(self, request):
+        check()
+        return make_call(filesystem_pb2_grpc.FilesystemServiceStub(channel).ListFolder, request)
+
+    def ReportUploadStatus(self, request):
+        check()
+        return make_call(filesystem_pb2_grpc.FilesystemServiceStub(channel).ReportUploadStatus, request)
+
+    def SetBlobStatus(self, request):
+        check()
+        return make_call(filesystem_pb2_grpc.FilesystemServiceStub(channel).SetBlobStatus, request)
+
+    def ShareFile(self, request):
+        check()
+        return make_call(filesystem_pb2_grpc.FilesystemServiceStub(channel).ShareFile, request)
+
+    def UploadPresigned(self, request):
+        check()
+        return make_call(filesystem_pb2_grpc.FilesystemServiceStub(channel).UploadPresigned, request)
+
+    def Blob(self, **kwargs):
+        return filesystem_pb2.Blob(**kwargs)
+
+    def CancelUploadRequest(self, **kwargs):
+        return filesystem_pb2.CancelUploadRequest(**kwargs)
+
+    def CancelUploadResponse(self, **kwargs):
+        return filesystem_pb2.CancelUploadResponse(**kwargs)
+
+    def CompleteUploadRequest(self, **kwargs):
+        return filesystem_pb2.CompleteUploadRequest(**kwargs)
+
+    def CompleteUploadResponse(self, **kwargs):
+        return filesystem_pb2.CompleteUploadResponse(**kwargs)
+
+    def CopyRequest(self, **kwargs):
+        return filesystem_pb2.CopyRequest(**kwargs)
+
+    def CreateFolderRequest(self, **kwargs):
+        return filesystem_pb2.CreateFolderRequest(**kwargs)
+
+    def CreateFolderResponse(self, **kwargs):
+        return filesystem_pb2.CreateFolderResponse(**kwargs)
+
+    def DeleteFileRequest(self, **kwargs):
+        return filesystem_pb2.DeleteFileRequest(**kwargs)
+
+    def DeleteFileResponse(self, **kwargs):
+        return filesystem_pb2.DeleteFileResponse(**kwargs)
+
+    def DeleteFolderRequest(self, **kwargs):
+        return filesystem_pb2.DeleteFolderRequest(**kwargs)
+
+    def DeleteFolderResponse(self, **kwargs):
+        return filesystem_pb2.DeleteFolderResponse(**kwargs)
+
+    def DownloadPresignedRequest(self, **kwargs):
+        return filesystem_pb2.DownloadPresignedRequest(**kwargs)
+
+    def DownloadPresignedResponse(self, **kwargs):
+        return filesystem_pb2.DownloadPresignedResponse(**kwargs)
+
+    def File(self, **kwargs):
+        return filesystem_pb2.File(**kwargs)
+
+    def GetBlobRequest(self, **kwargs):
+        return filesystem_pb2.GetBlobRequest(**kwargs)
+
+    def GetBlobResponse(self, **kwargs):
+        return filesystem_pb2.GetBlobResponse(**kwargs)
+
+    def GetFileRequest(self, **kwargs):
+        return filesystem_pb2.GetFileRequest(**kwargs)
+
+    def GetFileResponse(self, **kwargs):
+        return filesystem_pb2.GetFileResponse(**kwargs)
+
+    def ListBlobPointersRequest(self, **kwargs):
+        return filesystem_pb2.ListBlobPointersRequest(**kwargs)
+
+    def ListBlobPointersResponse(self, **kwargs):
+        return filesystem_pb2.ListBlobPointersResponse(**kwargs)
+
+    def ListBlobsRequest(self, **kwargs):
+        return filesystem_pb2.ListBlobsRequest(**kwargs)
+
+    def ListBlobsResponse(self, **kwargs):
+        return filesystem_pb2.ListBlobsResponse(**kwargs)
+
+    def ListFolderRequest(self, **kwargs):
+        return filesystem_pb2.ListFolderRequest(**kwargs)
+
+    def ListFolderResponse(self, **kwargs):
+        return filesystem_pb2.ListFolderResponse(**kwargs)
+
+    def Metadata(self, **kwargs):
+        return filesystem_pb2.Metadata(**kwargs)
+
+    def ReportUploadStatusRequest(self, **kwargs):
+        return filesystem_pb2.ReportUploadStatusRequest(**kwargs)
+
+    def ReportUploadStatusResponse(self, **kwargs):
+        return filesystem_pb2.ReportUploadStatusResponse(**kwargs)
+
+    def SetBlobStatusRequest(self, **kwargs):
+        return filesystem_pb2.SetBlobStatusRequest(**kwargs)
+
+    def SetBlobStatusResponse(self, **kwargs):
+        return filesystem_pb2.SetBlobStatusResponse(**kwargs)
+
+    def ShareFileRequest(self, **kwargs):
+        return filesystem_pb2.ShareFileRequest(**kwargs)
+
+    def ShareFileResponse(self, **kwargs):
+        return filesystem_pb2.ShareFileResponse(**kwargs)
+
+    def UploadPresignedRequest(self, **kwargs):
+        return filesystem_pb2.UploadPresignedRequest(**kwargs)
+
+    def UploadPresignedResponse(self, **kwargs):
+        return filesystem_pb2.UploadPresignedResponse(**kwargs)
+
+
+from . import common_pb2
+from . import common_pb2_grpc
+class CommonService:
+
+    def IntRangeFilter(self, **kwargs):
+        return common_pb2.IntRangeFilter(**kwargs)
+
+    def LongRangeFilter(self, **kwargs):
+        return common_pb2.LongRangeFilter(**kwargs)
+
+    def Organization(self, **kwargs):
+        return common_pb2.Organization(**kwargs)
+
+    def PageInfo(self, **kwargs):
+        return common_pb2.PageInfo(**kwargs)
+
+    def Picture(self, **kwargs):
+        return common_pb2.Picture(**kwargs)
+
+    def RateLimit(self, **kwargs):
+        return common_pb2.RateLimit(**kwargs)
+
+    def Region(self, **kwargs):
+        return common_pb2.Region(**kwargs)
+
+    def Thumbnail(self, **kwargs):
+        return common_pb2.Thumbnail(**kwargs)
+
+    def User(self, **kwargs):
+        return common_pb2.User(**kwargs)
 
